@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Compute the TF-IDF measure for ngram phrases
 
-our $VERSION = '0.0202';
+our $VERSION = '0.0203';
 
 use Moo;
 use strictures 2;
@@ -24,7 +24,7 @@ has files => (
 has size => (
     is      => 'ro',
     isa     => sub { croak 'Invalid integer' unless $_[0] && $_[0] =~ /^\d+$/ && $_[0] > 0 },
-    default => sub { 2 },
+    default => sub { 1 },
 );
 
 
@@ -145,7 +145,7 @@ Text::TFIDF::Ngram - Compute the TF-IDF measure for ngram phrases
 
 =head1 VERSION
 
-version 0.0202
+version 0.0203
 
 =head1 SYNOPSIS
 
@@ -155,9 +155,9 @@ version 0.0202
     size      => 3,
     stopwords => 1,
   );
-  my $w = $obj->tf( 'foo.txt', 'foo' );
+  my $w = $obj->tf( 'foo.txt', 'foo bar baz' );
   my $x = $obj->idf('foo');
-  my $y = $obj->tfidf( 'foo.txt', 'foo' );
+  my $y = $obj->tfidf( 'foo.txt', 'foo bar baz' );
   printf "TF: %.3f, IDF: %.3f, TFIDF: %.3f\n", $w, $x, $y;
   my $z = $obj->tfidf_by_file;
   print Dumper $z;
@@ -176,7 +176,7 @@ ArrayRef of filenames.
 
 =head2 size
 
-Integer ngram phrase size.
+Integer ngram phrase size.  Default is 1.
 
 =head2 stopwords
 
@@ -198,9 +198,7 @@ attribute - providing it in the constructor will be ignored.
   );
 
 Create a new C<Text::TFIDF::Ngram> object.  If the B<files> argument is passed
-in, populates the object using those files.
-
-The B<size> is the number of words in an ngram phrase and defaults to 2.
+in, the ngrams of each file is stored.
 
 =head2 BUILD
 
